#!/bin/sh

INSTALL_DIR="/usr/ibmprint"
PROGRAM_NAME="IBM Print Drivers"
PRODUCT_NAME="ibmprint"
VAR_DIR="/var/spool"/ibm/unix_prt_drivers/.${PRODUCT_NAME}

ARG="${1}"

check_for_root()
{
   #-- Make user the user is root
   if [ -x "/usr/bin/id" ];then ID_CMD="/usr/bin/id"; else ID_CMD="/bin/id" ; fi
   ${ID_CMD} | /bin/grep "uid=0">/dev/null 2>&1
   if [ "${?}" = "0" ]; then
      return 0
   else
      return 1
   fi
}

write_file()
{
   #-- Function no longer needed.
   echo >> /dev/null 
}

remove_file()
{
   #-- Function no longer needed.
   echo >> /dev/null 
}

suse_version()
{
    cat /etc/SuSE-release |grep "Server" >/dev/null 2>&1
    if [ $? -eq 0 ];then
       TYPE="`cat /etc/SuSE-release | sed 1q | awk '{print $3}'`"
       VERSION="`cat /etc/SuSE-release | sed 1q | awk '{print $5}'`"
       printf "\nSuSE Linux ${TYPE} Server [ ${VERSION} ] Distribution.\n\n"
    else
       VERSION="`cat /etc/SuSE-release | sed 1q | awk '{print $3}'`"
       printf "\nSuSE Linux [ ${VERSION} ] Distribution.\n\n"
    fi
    #expr ${VER} \>= 7.3 >/dev/null
}

redhat_version()
{
    VERSION="`cat /etc/redhat-release | awk '{print $5}'`"
    printf "\nRedHat [ ${VERSION} ] Distribution.\n\n"
}

mandrake_version()
{
    VERSION="`cat /etc/mandrake-release | awk '{print $4}'`"
    printf "\nMandrake Linux [ ${VERSION} ] Distribution. (Unsupported)\n\n"
}

linpus_version()
{
    VERSION="`cat /etc/linpus-release | awk '{print $4}'`"
    printf "\nLinpus [ ${VERSION} ] Distribution. (Unsupported)\n\n"
    #-- Set support for missing lp and lpstat links.
    check_for_root
    if [ $? -eq 0 ];then
       /bin/ls /usr/bin/lp /usr/bin/lpstat >/dev/null 2>&1
       if [ $? -ne 0 ];then
          /bin/touch ${VAR_DIR}/.linpus
       else
          if [ -f "${VAR_DIR}/.linpus" ];then
             rm -f ${VAR_DIR}/.linpus
          fi
       fi
    fi
}

lindows_version()
{
    VERSION="`cat /etc/lindowsos-version | awk '{print $3}'`"
    printf "\nLindows [ ${VERSION} ] Distribution. (Unsupported)\n\n"
}

redflag_version()
{
    VERSION="`cat /etc/redflag-release | awk '{print $5}'`"
    printf "\nRedflag [ ${VERSION} ] Distribution. (Unsupported)\n\n"

    #-- Set font.properties file.
    check_for_root
    if [ $? -eq 0 ];then
       cd ${INSTALL_DIR}/jre/lib
       if [ ! -f  "font.properties.zh.install" ];then
          /bin/cp -f font.properties.zh font.properties.zh.install
       fi
       /bin/cp -f font.properties.zh.Turbo font.properties.zh
    fi
    #-- Set font.properties file.
}

unknown_version()
{
    printf "\n Linux Distribution. (Unsupported)\n\n"
}

#-- Searching for System Distribution Type.
if   [ -f /etc/SuSE-release    ]; then
     suse_version 
     exit 0
elif [ -f /etc/linpus-release  ];then
     linpus_version
     exit 0
elif [ -f /etc/mandrake-release  ];then
     mandrake_version
     exit 0
elif [ -f /etc/redhat-release  ];then
     redhat_version
     exit 0
elif [ -f /etc/lindowsos-version ];then
     lindows_version
     exit 0
elif [ -f /etc/redflag-release   ];then
     redflag_version
     exit 0
else
     unknown_version
     exit 0
fi

# If we make it this far, we cannot determine the Linux Distribution.
# So we must ask.

printf "\n\n${PROGRAM_NAME} needs to know which Linux Distribution\n"
printf "this is.  Please select one of the following by the Number\n"
printf "Associated with the Linux Distribution.\n\n"
printf "1.  RedHat Linux 7.2, 7.3, 8.0, 9\n"
printf "2.  SuSE Linux   7.3, 8.0, 8.1, 8.2\n"

run=true
while  $run
do
  printf "\nSelect a number 1-2 > "
  read userver
  case $userver in
 
  1) run=false
     write_file 
     printf "\nRedHat Distribution.\n\n"
     printf "Done..\n\n"
     ;;
  2) run=false
     write_file 
     printf "\nSuSE Distribution.\n\n"
     printf "Done..\n\n"
     ;;
  esac
done

exit 0
